﻿'====================================================================
'   pas1000s.vb
'
'   Copyright (C) P&A Technologies Inc.
'====================================================================

Option Strict Off
Option Explicit On

Public Class pas1000s

    '----------------------------------------------------------------
    ' 定数
    '----------------------------------------------------------------
    ' 分解能
    Private Const DATA_RESOLUTION As Double = 65536
    ' USB転送モード
    Private ReadOnly STR_USB_MODE() As String = {"FULL SPEED", "HI SPEED"}
    ' 曜日
    Private ReadOnly STR_WEEK() As String = {"日", "月", "火", "水", "木", "金", "土"}
    ' 動作モード
    Private ReadOnly STR_ENABLE() As String = {"無効", "有効"}
    Private ReadOnly STR_ANALOG_TYPE() As String = {"電圧", "", "", "", "", "", "", "", "", "測温抵抗体"}
    Private ReadOnly STR_ANALOG_RANGE() As String = {"±100mV", "±200mV", "±500mV", "±1V", "±2V", "±5V", _
                                                     "±10V", "±20V", "±50V", "±100V"}
    Private ReadOnly STR_ANALOG_RANGE_UNIT() As String = {"mV", "mV", "mV", "V", "V", "V", "V", "V", "V", "V"}
    Private ReadOnly STR_ANALOG_SMPMODE() As String = {"ノーマル", "アベレージ"}
    Private ReadOnly VALUE_ANALOG_RANGE() As Double = {100, 200, 500, 1, 2, 5, 10, 20, 50, 100}
    ' ステータス
    Private ReadOnly STR_LOG_STATUS() As String = {"ロギング停止", "ロギング実行中"}
    Private ReadOnly STR_OVERRUN_ERROR() As String = {"エラーなし", "ハードバッファエラー", "ソフトバッファエラー"}

    '----------------------------------------------------------------
    ' 変数
    '----------------------------------------------------------------
    ' pas1000クラス
    Dim Pas1000w As pas1000

    ''' <summary>
    ''' フォームロード時の処理。
    ''' </summary>
    ''' <param name="sender">メッセージ送信元オブジェクト</param>
    ''' <param name="e">イベント内容</param>
    Private Sub pas1000s_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim szBuf As String
        Dim i, j, num As Integer

        Dim wDeviceNo As UShort
        Dim dwDrvVer, dwDllVer As UInteger
        Dim DevInfo As pas1000.TDEVINFO
        Dim szVid, szPid As String
        Dim dwUnitId, dwNumCh, dwMaxNumCh As UInteger
        Dim dt As DateTime
        Dim dwHostTime(), dwFirmTime(), dwFpgaTime() As Integer
        Dim dwAdjStatus As UInteger
        Dim SetMode As pas1000.TSETMODE
        Dim szCh As String
        Dim dwStartMode As UInteger
        Dim dwSmpTime As UInteger
        Dim szSmpTime As String
        Dim dwHardNumData, dwSoftNumData, dwLogStatus, dwOverrunError As UInteger
        Dim bLogBuf() As Byte
        Dim DispCh As Integer
        Dim bTmStampBuf() As Byte
        Dim dwTmStamp As ULong
        Dim bEv, bCh As Byte
        Dim szTmStamp, szData As String
        Dim bInValue As Byte

        ' 変数を初期化
        Pas1000w = New pas1000()
        wDeviceNo = pas1000.DEVICE_AUTO
        dwDrvVer = 0
        dwDllVer = 0
        DevInfo = New pas1000.TDEVINFO()
        DevInfo.bVendorID = New Byte(pas1000.VID_LENGTH - 1) {}
        DevInfo.bProductID = New Byte(pas1000.PID_LENGTH - 1) {}
        szVid = ""
        szPid = ""
        dwUnitId = 0
        dwNumCh = 0
        dwHostTime = New Integer(pas1000.DATE_TIME_LENGTH - 1) {}
        dwFirmTime = New Integer(pas1000.DATE_TIME_LENGTH - 1) {}
        dwFpgaTime = New Integer(pas1000.DATE_TIME_LENGTH - 1) {}
        dwAdjStatus = 0
        SetMode = New pas1000.TSETMODE()
        SetMode.Analog = New pas1000.TANALOG()
        SetMode.Analog.Ch = New pas1000.TANALOGCH(pas1000.ANALOG_NUM_CH - 1) {}
        SetMode.Analog.StartTrig = New pas1000.TTRIG()
        SetMode.Analog.StopTrig = New pas1000.TTRIG()
        SetMode.Analog.dwStartTime = New UInteger(pas1000.START_TIME_LENGTH - 1) {}
        SetMode.ExTrig = New pas1000.TEXTRIG(pas1000.EXTRIG_NUM_CH - 1) {}
        SetMode.Alarm = New pas1000.TALARM()
        SetMode.Alarm.Analog = New pas1000.TALARMANALOG(pas1000.ANALOG_NUM_CH - 1) {}
        SetMode.DigitalOut = New pas1000.TDIGITALOUT(pas1000.DIGITALOUT_NUM_CH - 1) {}
        szCh = ""
        dwStartMode = 0
        szSmpTime = ""
        dwHardNumData = 0
        dwSoftNumData = 0
        dwLogStatus = 0
        dwOverrunError = 0
        DispCh = -1
        bTmStampBuf = New Byte(7) {}
        szTmStamp = ""
        szData = ""
        bInValue = 0

        '------------------------------------------------------------
        ' デバイスの初期化処理
        '------------------------------------------------------------
        If Pas1000w.Initialize(0, 0, -1) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If

        '------------------------------------------------------------
        ' デバイスの検索
        '------------------------------------------------------------
        If Pas1000w.Create(wDeviceNo) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        szBuf = String.Format("デバイス {0} の使用を宣言しました。", wDeviceNo)
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' バージョン情報を取得
        '------------------------------------------------------------
        If Pas1000w.GetVersion(dwDrvVer, dwDllVer) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        szBuf = String.Concat("<< バージョン情報 >>" + Chr(10), _
                              String.Format("    ドライバ : {0:X8}H" + Chr(10), dwDrvVer), _
                              String.Format("    DLL : {0:X8}H", dwDllVer))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' デバイス情報を取得
        '------------------------------------------------------------
        If Pas1000w.GetDevInfo(wDeviceNo, DevInfo) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        For i = 0 To pas1000.VID_LENGTH - 1
            If Chr(DevInfo.bVendorID(i)) = " " Then Exit For
            szVid = String.Concat(szVid, Chr(DevInfo.bVendorID(i)))
        Next
        For i = 0 To pas1000.PID_LENGTH - 1
            If Chr(DevInfo.bProductID(i)) = " " Then Exit For
            szPid = String.Concat(szPid, Chr(DevInfo.bProductID(i)))
        Next
        szBuf = String.Concat("<< デバイス情報 >>" + Chr(10), _
                              String.Format("    ベンダ ID : {0}" + Chr(10), szVid), _
                              String.Format("    プロダクト ID : {0}" + Chr(10), szPid), _
                              String.Format("    ファームバージョン : {0}.{1:D2}" + Chr(10), DevInfo.bFirmVer \ 100, DevInfo.bFirmVer Mod 100), _
                              String.Format("    FPGA バージョン : {0}.{1:D2}" + Chr(10), DevInfo.bFpgaVer \ 100, DevInfo.bFpgaVer Mod 100), _
                              String.Format("    USB 転送モード : {0}", STR_USB_MODE(DevInfo.bUsbMode)))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' ユニット情報を取得
        '------------------------------------------------------------
        If Pas1000w.GetUnitInfo(wDeviceNo, dwUnitId, dwNumCh) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        dwMaxNumCh = (dwNumCh + 1) * 4
        szBuf = String.Concat("<< ユニット情報 >>" + Chr(10), _
                              String.Format("    ユニット ID : {0}" + Chr(10), dwUnitId), _
                              String.Format("    アナログチャンネル数 : {0}CH", dwMaxNumCh))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' 時刻の設定
        '------------------------------------------------------------
        dt = DateTime.Now                               ' 現在の時刻を取得
        dwHostTime(0) = dt.Year - 2000                  ' 年(下2桁)
        dwHostTime(1) = dt.Month                        ' 月
        dwHostTime(2) = dt.Day                          ' 日
        dwHostTime(3) = CType(dt.DayOfWeek, Integer)    ' 曜
        dwHostTime(4) = dt.Hour                         ' 時
        dwHostTime(5) = dt.Minute                       ' 分
        dwHostTime(6) = dt.Second                       ' 秒
        If Pas1000w.SetTime(wDeviceNo, dwHostTime) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If

        '------------------------------------------------------------
        ' 時刻を取得
        '------------------------------------------------------------
        If Pas1000w.GetTime(wDeviceNo, dwFirmTime, dwFpgaTime, dwAdjStatus) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        szBuf = String.Concat("<< 時刻 >>" + Chr(10), _
                              String.Format("    ファーム : 20{0:D2}/{1:D2}/{2:D2}({3}) {4:D2}:{5:D2}:{6:D2}" + Chr(10), _
                                            dwFirmTime(0), dwFirmTime(1), dwFirmTime(2), STR_WEEK(dwFirmTime(3)), _
                                            dwFirmTime(4), dwFirmTime(5), dwFirmTime(6)), _
                              String.Format("    FPGA : 20{0:D2}/{1:D2}/{2:D2} {3:D2}:{4:D2}:{5:D2}" + Chr(10), _
                                            dwFpgaTime(0), dwFpgaTime(1), dwFpgaTime(2), _
                                            dwFpgaTime(4), dwFpgaTime(5), dwFpgaTime(6)))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' 動作モードの設定
        '------------------------------------------------------------
        ' アナログ
        For i = 0 To pas1000.ANALOG_NUM_CH - 1
            If i >= dwMaxNumCh Then Exit For
            SetMode.Analog.Ch(i).dwChEnable = 1         ' チャンネル:有効
            SetMode.Analog.Ch(i).dwType = 0             ' 入力タイプ:電圧
            SetMode.Analog.Ch(i).dwRange = 6            ' 入力レンジ:±10V
        Next

        SetMode.Analog.StartTrig.dwEnable = 0           ' スタートトリガ:無効
        SetMode.Analog.StopTrig.dwEnable = 0            ' ストップトリガ:無効
        SetMode.Analog.dwSamplingMode = 1               ' サンプリングモード:アベレージ
        SetMode.Analog.dwSamplingTime = 1000            ' サンプリングタイム:1ms
        SetMode.Analog.dwStartTimeEnable = 0            ' スタートタイム:無効
        SetMode.Analog.dwLoggingSize = 1000             ' ロギングサイズ:1000(1秒間)
        ' 外部トリガ
        For i = 0 To pas1000.EXTRIG_NUM_CH - 1
            SetMode.ExTrig(i).dwInSlope = 0             ' 入力スロープ:↑
            SetMode.ExTrig(i).dwInFilter = 0            ' 入力フィルタ:0ms
        Next
        ' アラーム
        For i = 0 To pas1000.ANALOG_NUM_CH - 1
            If i >= dwMaxNumCh Then Exit For
            SetMode.Alarm.Analog(i).dwEnable = 0        ' アナログアラーム:無効
        Next
        SetMode.Alarm.ExTrig.dwEnable = 0               ' 外部トリガアラーム:無効
        ' デジタル出力
        For i = 0 To pas1000.DIGITALOUT_NUM_CH - 1
            SetMode.DigitalOut(i).dwType = 0            ' 出力タイプ:デジタル出力の設定値を反映
        Next
        If Pas1000w.SetMode(wDeviceNo, SetMode) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        For i = 0 To pas1000.ANALOG_NUM_CH - 1
            If SetMode.Analog.Ch(i).dwChEnable = 0 Then Continue For
            If szCh <> "" Then
                szCh = String.Concat(szCh, "/")
            End If
            szCh = String.Concat(szCh, String.Format("CH{0}", i + 1))

            If DispCh = -1 Then
                DispCh = i                              ' 結果表示用チャンネルを設定
            End If
        Next
        dwSmpTime = SetMode.Analog.dwSamplingTime
        If dwSmpTime < 1000 Then
            szSmpTime = "μs"
        ElseIf dwSmpTime < 1000000 Then
            dwSmpTime /= 1000
            szSmpTime = "ms"
        Else
            dwSmpTime /= (1000 * 1000)
            szSmpTime = "s"
        End If
        szBuf = String.Concat("<< 動作モード ( アナログ ) >>" + Chr(10), _
                              String.Format("    チャンネル : {0}" + Chr(10), szCh), _
                              String.Format("    入力タイプ : {0}" + Chr(10), STR_ANALOG_TYPE(SetMode.Analog.Ch(DispCh).dwType)), _
                              String.Format("    入力レンジ : {0}" + Chr(10), STR_ANALOG_RANGE(SetMode.Analog.Ch(DispCh).dwRange)), _
                              String.Format("    スタートトリガ : {0}" + Chr(10), STR_ENABLE(SetMode.Analog.StartTrig.dwEnable)), _
                              String.Format("    ストップトリガ : {0}" + Chr(10), STR_ENABLE(SetMode.Analog.StopTrig.dwEnable)), _
                              String.Format("    サンプリングモード : {0}" + Chr(10), STR_ANALOG_SMPMODE(SetMode.Analog.dwSamplingMode)), _
                              String.Format("    サンプリングタイム : {0}{1}" + Chr(10), dwSmpTime, szSmpTime), _
                              String.Format("    スタートタイム : {0}" + Chr(10), STR_ENABLE(SetMode.Analog.dwStartTimeEnable)), _
                              String.Format("    ロギングサイズ : {0}" + Chr(10), SetMode.Analog.dwLoggingSize))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' ロギングの開始
        '------------------------------------------------------------
        For i = 0 To pas1000.ANALOG_NUM_CH - 1
            If i >= dwMaxNumCh Then Exit For
            If SetMode.Analog.Ch(i).dwChEnable = 1 Then
                dwStartMode = dwStartMode Or (1 << i)
            End If
        Next
        szCh = ""
        For i = 0 To pas1000.ANALOG_NUM_CH - 1
            If (dwStartMode And (1 << i)) = 0 Then Continue For
            If szCh <> "" Then
                szCh = String.Concat(szCh, "/")
            End If
            szCh = String.Concat(szCh, String.Format("CH{0}", i + 1))
        Next
        szBuf = String.Concat("<< ロギング開始 >>" + Chr(10), _
                              String.Format("    アナログチャンネル : {0}" + Chr(10) + Chr(10), szCh), _
                              " ※ロギングは自動的に停止します。" + Chr(10), _
                              "    << ロギング停止 >> と表示されるまでお待ちください。")
        ResultMessage(szBuf)
        If Pas1000w.StartLogging(wDeviceNo, dwStartMode) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        System.Threading.Thread.Sleep(1000)             ' 1秒待ち

        ' ロギング終了待ち
        While True
            '--------------------------------------------------------
            ' チャンネル共通のステータスを取得
            '--------------------------------------------------------
            If Pas1000w.GetStatus(wDeviceNo, dwHardNumData, dwSoftNumData, dwLogStatus, dwOverrunError) = False Then
                ErrorMessage(wDeviceNo)
                GoTo END_PROCESS
            End If
            ' 全チャンネルのロギング停止で、ハードバッファのロギングデータ数が 0 の場合、ロギング終了
            If (dwLogStatus = pas1000.STOP_LOGGING) AndAlso (dwHardNumData = 0) Then Exit While
        End While

        '------------------------------------------------------------
        ' ロギングの停止
        '------------------------------------------------------------
        If Pas1000w.StopLogging(wDeviceNo) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        ResultMessage("<< ロギング停止 >>")

        '------------------------------------------------------------
        ' チャンネル共通のステータスを取得
        '------------------------------------------------------------
        If Pas1000w.GetStatus(wDeviceNo, dwHardNumData, dwSoftNumData, dwLogStatus, dwOverrunError) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        szBuf = String.Concat("<< チャンネル共通のステータス >>" + Chr(10), _
                              String.Format("    ハードバッファ : {0} ポイント" + Chr(10), dwHardNumData), _
                              String.Format("    ソフトバッファ : {0} ポイント" + Chr(10), dwSoftNumData), _
                              String.Format("    ロギングステータス : {0}" + Chr(10), STR_LOG_STATUS(dwLogStatus)), _
                              String.Format("    オーバーランエラー : {0}", STR_OVERRUN_ERROR(dwOverrunError)))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' ロギングデータを取得
        '------------------------------------------------------------
        bLogBuf = New Byte(dwSoftNumData * 3) {}
        If Pas1000w.GetData(wDeviceNo, dwSoftNumData, bLogBuf) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        j = 0
        num = 1
        For i = 0 To bLogBuf.Length - 1 Step 3
            bEv = bLogBuf(i) And &HE0                   ' イベント情報
            bCh = bLogBuf(i) And &HF                    ' チャンネル情報

            ' 表示用チャンネルのデータを取得
            If bCh = DispCh Then
                ' タイムスタンプ
                If bEv <> 0 Then
                    bTmStampBuf(j) = bLogBuf(i + 1)
                    j += 1
                    bTmStampBuf(j) = bLogBuf(i + 2)
                    j += 1
                ' データ
                Else
                    szData = String.Concat(szData, _
                                            String.Format("       {0} : {1:X2}{2:X2}H", num, bLogBuf(i + 1), bLogBuf(i + 2)), _
                                            String.Format(" ( {0:f5} )" + Chr(10), VoltValue(SetMode.Analog.Ch(DispCh).dwRange, _
                                                                                             (CType(bLogBuf(i + 1), UInteger) << 8) _
                                                                                                Or CType(bLogBuf(i + 2), UInteger))))
                    If num = 10 Then Exit For           ' 10個分表示
                    num += 1
                End If
            End If
        Next
        dwTmStamp = (CType(bTmStampBuf(0), ULong) << 56) _
                        Or (CType(bTmStampBuf(1), ULong) << 48) _
                        Or (CType(bTmStampBuf(2), ULong) << 40) _
                        Or (CType(bTmStampBuf(3), ULong) << 32) _
                        Or (CType(bTmStampBuf(4), ULong) << 24) _
                        Or (CType(bTmStampBuf(5), ULong) << 16) _
                        Or (CType(bTmStampBuf(6), ULong) << 8) _
                        Or CType(bTmStampBuf(7), ULong)
        szTmStamp = String.Format("{0:D2}/{1:D2}/{2:D2} {3:D2}:{4:D2}:{5:D2}.{6:D6}", _
                                  ((dwTmStamp >> 46) And &H7F), _
                                  ((dwTmStamp >> 42) And &HF), _
                                  ((dwTmStamp >> 37) And &H1F), _
                                  ((dwTmStamp >> 32) And &H1F), _
                                  ((dwTmStamp >> 26) And &H3F), _
                                  ((dwTmStamp >> 20) And &H3F), _
                                  (dwTmStamp And &HFFFFF))
        szBuf = String.Concat("<< ロギングデータ >>" + Chr(10), _
                              String.Format("    アナログチャンネル : CH{0}" + Chr(10), DispCh + 1), _
                              String.Format("    タイムスタンプ : {0}" + Chr(10) + Chr(10), szTmStamp), _
                              String.Format("    データ [ {0} ポイント ]" + Chr(10) + "{1}" + Chr(10), num, szData), _
                              String.Format("    ※カッコ内は電圧値 ( 単位 : {0} )", _
                                            STR_ANALOG_RANGE_UNIT(SetMode.Analog.Ch(DispCh).dwRange)))
        ResultMessage(szBuf)

        '------------------------------------------------------------
        ' デジタル入力の読み込み
        '------------------------------------------------------------
        If Pas1000w.DigitalIn(wDeviceNo, bInValue) = False Then
            ErrorMessage(wDeviceNo)
            GoTo END_PROCESS
        End If
        szBuf = String.Concat("<< デジタル入力 >>" + Chr(10), _
                              String.Format("    読み込みデータ : {0:X2}H", bInValue))
        ResultMessage(szBuf)

END_PROCESS:
        '------------------------------------------------------------
        ' デバイスの開放
        '------------------------------------------------------------
        If wDeviceNo <> pas1000.DEVICE_AUTO Then
            If Pas1000w.Close(wDeviceNo) = False Then
                ErrorMessage(wDeviceNo)
            End If
            szBuf = String.Format("デバイス {0} を開放しました。", wDeviceNo)
            ResultMessage(szBuf)
        End If

        '------------------------------------------------------------
        ' デバイスの終了処理
        '------------------------------------------------------------
        Pas1000w.Terminate()

        Me.Close()
    End Sub

    ''' <summary>
    ''' ロギングデータを電圧値に換算。
    ''' </summary>
    ''' <param name="dwRange">入力レンジ</param>
    ''' <param name="dwData">ロギングデータ</param>
    ''' <returns>電圧値</returns>
    Private Function VoltValue(ByVal dwRange As UInteger, ByVal dwData As UInteger) As Double
        Dim Vmax, Vmin As Double
        
        Vmax = VALUE_ANALOG_RANGE(dwRange)
        Vmin = -Vmax
        Return ((Vmax - Vmin) * dwData / DATA_RESOLUTION + Vmin)
    End Function

    ''' <summary>
    ''' 処理結果を表示。
    ''' </summary>
    ''' <param name="strMsg">表示するメッセージ文字列</param>
    Private Sub ResultMessage(ByVal strMsg As String)
        MessageBox.Show(strMsg, Me.Text, MessageBoxButtons.OK, MessageBoxIcon.Information)
    End Sub

    ''' <summary>
    ''' エラーメッセージを表示。
    ''' </summary>
    ''' <param name="wDeviceNo">エラー情報を取得するデバイス識別番号</param>
    Private Sub ErrorMessage(ByVal wDeviceNo As UShort)
        Dim dwRes As UInteger
        Dim szBuf As String

        dwRes = Pas1000w.GetLastError(wDeviceNo)
        szBuf = GetErrorStr(dwRes)
        MessageBox.Show(szBuf, Me.Text, MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Sub

    ''' <summary>
    ''' エラー文字列を取得。
    ''' </summary>
    ''' <param name="dwRes">エラー番号</param>
    ''' <returns>エラー文字列</returns>
    Private Function GetErrorStr(ByVal dwRes As UInteger) As String
        Dim szBuf As String

        Select Case (dwRes And &HFFFF)
            Case pas1000.ERR_SYSTEM
                GetErrorStr = "システムエラーです。"
            Case pas1000.ERR_NO_DEVICE
                GetErrorStr = "使用可能なデバイスがありません。"
            Case pas1000.ERR_IN_USE
                GetErrorStr = "指定のデバイスは使用中です。"
            Case pas1000.ERR_INVALID_DEVICENO
                GetErrorStr = "不正なデバイス識別番号です。"
            Case pas1000.ERR_INVALID_ARGUMENT
                szBuf = "不正な引数が指定されました。"
                If (dwRes >> 16) <> 0 Then
                    szBuf = String.Concat(szBuf, String.Format(Chr(10) + "[ Error code : {0:X4}H ]", dwRes >> 16))
                End If
                GetErrorStr = szBuf
            Case pas1000.ERR_INTERNAL
                GetErrorStr = "内部エラーです。"
            Case pas1000.ERR_TRANSFER_TIMEOUT
                GetErrorStr = "データ転送がタイムアウトになりました。"
            Case pas1000.ERR_TRANSFER_CANCEL
                GetErrorStr = "データ転送がキャンセルされました。"
            Case pas1000.ERR_TRANSFER_FAIL
                GetErrorStr = "データ転送が失敗しました。"
            Case pas1000.ERR_TRANSFER_SIZE
                GetErrorStr = "データ転送のサイズが不正です。"
            Case pas1000.ERR_HARDBUFF_OVERRUN
                GetErrorStr = "ハードバッファがオーバーランしました。"
            Case pas1000.ERR_SOFTBUFF_OVERRUN
                GetErrorStr = "ソフトバッファがオーバーランしました。"
            Case pas1000.ERR_DEVICE
                szBuf = "デバイスエラーです。"
                If (dwRes >> 16) <> 0 Then
                    szBuf = String.Concat(szBuf, String.Format(Chr(10) + "[ Error code : {0:X4}H ]", dwRes >> 16))
                End If
                GetErrorStr = szBuf
            Case pas1000.ERR_WRAPDLL
                GetErrorStr = "DLL のロードに失敗しました。"
            Case Else
                GetErrorStr = String.Format("未定義のエラーです。" + Chr(10) + "[ Error code : {0:X8}H ]", dwRes)
        End Select
    End Function

End Class
